@@ -1,4 +1,3 @@
-
 package R::YapRI;
 
 
@@ -8,15 +7,16 @@ package R::YapRI;
 
 =head1 NAME
 
-R::YapRI.pm
-
-Just the doc. for R::YapRI modules.
+R::YapRI - Yet Another Perl R Inteface
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 $VERSION = eval $VERSION;
 
+1;
+__END__
+
 =head1 SYNOPSIS
 
   use R::YapRI::Base;
@@ -29,7 +29,7 @@ $VERSION = eval $VERSION;
   $rbase->add_command('plot(c(1, 5, 10), type = "l")');
   $rbase->add_command('dev.off()');
  
-  $rbase->run_command();
+  $rbase->run_commands();
   
   my $result_file = $rbase->get_result_file();
   
@@ -39,23 +39,16 @@ $VERSION = eval $VERSION;
 =head1 DESCRIPTION
 
 Yet another perl wrapper to interact with R. 
-R::YapRI are a collection of modules to interact with R using Perl.
+C<R::YapRI> is a collection of modules to interact with R using Perl.
 
-The mechanism is simple, it write R commands into a command file and 
-executate it using the R as command line: 
-   
-R [options] < infile > outfile
+The mechanism is simple, it writes R commands into a command file and 
+execute it using the R as command line: 
 
- use R::YapRI::Base;
- my $rbase = R::YapRI::Base->new();
- $rbase->add_command('x <- c(1:10)');
- $rbase->add_command('y <- c(2,3,5,7,11,13,17,19,23,29)');
- $rbase->add_command('x * y');
- my $resultfile = $rbase->get_result_file();
+ R [options] < infile > outfile
 
-More information about the basic usage can be found: L<R::YapRI::Base>.
+More information about the basic usage can be found in L<R::YapRI::Base>.
 
-But there are some tricks, it can define blocks and combine them, so it can
+But there are some tricks. It can also define blocks and combine them, so it can
 extend the interaction between packages of information. For example, it can
 create a block to check the length of a vector using default as base
 
@@ -74,23 +67,34 @@ create a block to check the length of a vector using default as base
 More information about the use of blocks can be found at L<R::YapRI::Block>.
 
 It can use interpreters (L<R::YapRI::Interpreter::Perl>), so sometimes
-it can use perl hashref. instead strings to add_commands.
+it can use perl HASHREF instead of strings to C<add_command>.
 
  $rbase->add_command('mean(c(2,3,5,7,11,13,17,19,23,29))');
  $rbase->add_command({ mean => [2,3,5,7,11,13,17,19,23,29]});
 
 It uses two switches to trace the R commands that you are running:
 
-- disable_keepfiles/enable_keepfiles, to do not delete the command files and
-the result files after the executation of the code.
+=over 4
 
-- disable_debug/enable_debug, to print as STDERR the R commands from the 
-command file before executate them.
+=item *
 
-There are some examples of modules that wrap L<R::YapRI::Base> for an extended 
+disable_keepfiles/enable_keepfiles, to not delete the command files and
+the result files after the execution of the code.
+
+=item *
+
+disable_debug/enable_debug, to print to C<STDERR> the R commands from the 
+command file before executing them.
+
+=back
+
+
+=head1 ADVANCED FEATURES
+
+Here are some examples of modules that wrap L<R::YapRI::Base> for an extended 
 functionality.
 
-* Matrix manipulation L<R::YapRI::Data::Matrix>
+=head2 Matrix manipulation L<R::YapRI::Data::Matrix>
 
   use R::YapRI::Base;
   use R::YapRI::Data::Matrix;
@@ -111,7 +115,7 @@ functionality.
   my $eigenvectors = read_rbase($rbase, 'BLOCK1', 'eigenvect1');
 
 
-* Simple graph creation L<R::YapRI::Graph::Simple>
+=head2 Simple graph creation L<R::YapRI::Graph::Simple>
 
   use R::YapRI::Base;
   use R::YapRI::Data::Matrix;
@@ -146,18 +150,34 @@ functionality.
 
 =head1 AUTHOR
 
-Aureliano Bombarely <ab782@cornell.edu>
+Aureliano Bombarely <aurebg@vt.edu>
 
 =head1 ACKNOWLEDGEMENTS
 
+=over 4
+
+=item *
+
 Lukas Mueller
 
+=item *
+
 Robert Buels
 
+=item *
+
 Naama Menda
 
+=item *
+
 Jonathan "Duke" Leto
 
+=item *
+
+Olivier "dolmen" MenguE<eacute>
+
+=back
+
 =head1 PUBLIC REPOSITORY
 
 Hosted at GitHub: L<https://github.com/solgenomics/yapri>
