@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use autodie;
 
-use Carp qw(croak cluck);
+use Carp qw(croak cluck carp);
 use R::YapRI::Base;
 use R::YapRI::Interpreter::Perl qw( r_var );
 
@@ -22,7 +22,7 @@ A module to build and pass a Matrix to a YapRI command file
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -32,7 +32,7 @@ $VERSION = eval $VERSION;
 
   ## Constructors:
 
-  my $rmatrix = R::YapRI::Data::Matrix->new('matrix1');
+  my $rmatrix = R::YapRI::Data::Matrix->new({ name => 'matrix1' });
   
   ## Accessors:
 
@@ -109,7 +109,7 @@ in a rbase block.
 
 =head1 AUTHOR
 
-Aureliano Bombarely <ab782@cornell.edu>
+Aureliano Bombarely <aurebg@vt.edu>
 
 
 =head1 CLASS METHODS
@@ -144,6 +144,7 @@ The following class methods are implemented:
         
   Side_Effects: Die if the argument used is not a hash or its values arent 
                 right.
+                If no coln and rown are used, it will set to 0 by default.
 
   Example: my $rmatrix = R::YapRI::Data::Matrix->new(
                                      { 
@@ -215,10 +216,10 @@ sub new {
     my $name = $args{name} || '';
     $self->set_name($name);
 
-    my $coln = $args{coln} || '';
+    my $coln = $args{coln} || 0;
     $self->set_coln($coln);
 
-    my $rown = $args{rown} || '';
+    my $rown = $args{rown} || 0;
     $self->set_rown($rown);
 
     my $colnames = $args{colnames} || [];
@@ -1368,7 +1369,7 @@ sub change_columns {
     my $a = 0;
     foreach my $data (@data) {
 	my ($r, $c) = @{$revindex{$a}};
-	foreach my $colnm (keys %col_index) {
+	foreach my $colnm (sort keys %col_index) {
 	    if ($col_index{$colnm} == $c) {
 		push @{$col_data{$colnm}}, $data;
 	    }
@@ -1385,7 +1386,7 @@ sub change_columns {
 	$colname1 => $colname2,
 	);
 
-    foreach my $chname (keys %changed) {	
+    foreach my $chname (sort keys %changed) {	
 	$self->set_coldata($chname, $col_data{$changed{$chname}});
 	
 	my $old_idx = $col_index{$chname};
@@ -1428,7 +1429,7 @@ sub change_rows {
     my @rownames = @{$self->get_rownames()};
     my ($n, $match) = (0, 0);
     foreach my $row (@rownames) {
-	foreach my $selrow (keys %row_index) {
+	foreach my $selrow (sort keys %row_index) {
 	    if ($row eq $selrow) {
 		$row_index{$selrow} = $n;
 		$match++;
@@ -1452,7 +1453,7 @@ sub change_rows {
     my $a = 0;
     foreach my $data (@data) {
 	my ($r, $c) = @{$revindex{$a}};
-	foreach my $rownm (keys %row_index) {
+	foreach my $rownm (sort keys %row_index) {
 	    if ($row_index{$rownm} == $r) {
 		push @{$row_data{$rownm}}, $data;
 	    }
@@ -1469,7 +1470,7 @@ sub change_rows {
 	$rowname1 => $rowname2,
 	);
 
-    foreach my $chname (keys %changed) {	
+    foreach my $chname (sort keys %changed) {	
 	$self->set_rowdata($chname, $row_data{$changed{$chname}});
 	
 	my $old_idx = $row_index{$chname};
